@@ -1,4 +1,3 @@
-
 from typing import Optional, Tuple
 from paramak import RotateStraightShape
 
@@ -10,6 +9,7 @@ class CenterColumnShieldCylinder(RotateStraightShape):
         height: height of the center column shield.
         inner_radius: the inner radius of the center column shield.
         outer_radius: the outer radius of the center column shield.
+        center_height: the vertical height of the center of the component.
         stp_filename: Defaults to "CenterColumnShieldCylinder.stp".
         stl_filename: Defaults to "CenterColumnShieldCylinder.stl".
         material_tag: Defaults to "center_column_shield_mat".
@@ -20,11 +20,16 @@ class CenterColumnShieldCylinder(RotateStraightShape):
         height: float,
         inner_radius: float,
         outer_radius: float,
+        center_height: Optional[float] = 0,
+        name: Optional[str] = "CenterColumnShieldCylinder",
         stp_filename: Optional[str] = "CenterColumnShieldCylinder.stp",
         stl_filename: Optional[str] = "CenterColumnShieldCylinder.stl",
         material_tag: Optional[str] = "center_column_shield_mat",
-        color: Optional[Tuple[float, float, float,
-                              Optional[float]]] = (0., 0.333, 0.),
+        color: Optional[Tuple[float, float, float, Optional[float]]] = (
+            0.0,
+            0.333,
+            0.0,
+        ),
         **kwargs
     ) -> None:
 
@@ -33,12 +38,27 @@ class CenterColumnShieldCylinder(RotateStraightShape):
             stp_filename=stp_filename,
             stl_filename=stl_filename,
             color=color,
+            name=name,
             **kwargs
         )
 
         self.height = height
         self.inner_radius = inner_radius
         self.outer_radius = outer_radius
+        self.center_height = center_height
+
+    @property
+    def center_height(self):
+        return self._center_height
+
+    @center_height.setter
+    def center_height(self, value):
+        if not isinstance(value, (int, float)):
+            msg = (
+                f'CenterColumnShieldBlock.center_height should be a float or int. Not a {type(value)}')
+            raise TypeError(msg)
+
+        self._center_height = value
 
     @property
     def height(self):
@@ -59,9 +79,9 @@ class CenterColumnShieldCylinder(RotateStraightShape):
     def inner_radius(self, value):
         if hasattr(self, "outer_radius"):
             if value >= self.outer_radius:
-                raise ValueError(
-                    "inner_radius ({}) is larger than outer_radius ({})".format(
-                        value, self.outer_radius))
+                msg = (f'inner_radius ({value}) is larger than outer_radius '
+                       '({self.outer_radius})')
+                raise ValueError(msg)
         self._inner_radius = value
 
     @property
@@ -72,9 +92,10 @@ class CenterColumnShieldCylinder(RotateStraightShape):
     def outer_radius(self, value):
         if hasattr(self, "inner_radius"):
             if value <= self.inner_radius:
-                raise ValueError(
-                    "inner_radius ({}) is larger than outer_radius ({})".format(
-                        self.inner_radius, value))
+                msg = (f'inner_radius ({self.inner_radius}) is larger than '
+                       'outer_radius ({value})')
+                raise ValueError(msg)
+
         self._outer_radius = value
 
     def find_points(self):
@@ -82,10 +103,10 @@ class CenterColumnShieldCylinder(RotateStraightShape):
             2D profile of the center column shield shape."""
 
         points = [
-            (self.inner_radius, self.height / 2),
-            (self.outer_radius, self.height / 2),
-            (self.outer_radius, -self.height / 2),
-            (self.inner_radius, -self.height / 2),
+            (self.inner_radius, self.center_height + self.height / 2),
+            (self.outer_radius, self.center_height + self.height / 2),
+            (self.outer_radius, self.center_height + (-self.height / 2)),
+            (self.inner_radius, self.center_height + (-self.height / 2)),
         ]
 
         self.points = points
