@@ -14,7 +14,7 @@ class TestExampleComponents(unittest.TestCase):
     def test_jupyter_notebooks_example_parametric_components(self):
         for notebook in Path().rglob("examples/example_parametric_components/*.ipynb"):
             print(notebook)
-            nb, errors = notebook_run(notebook)
+            errors = notebook_run(notebook)
             assert errors == []
 
 
