@@ -24,8 +24,9 @@ class TestSegmentedBlanketBallReactor(unittest.TestCase):
             rotation_angle=180,
             pf_coil_radial_thicknesses=[50, 50, 50, 50],
             pf_coil_vertical_thicknesses=[50, 50, 50, 50],
-            pf_coil_to_rear_blanket_radial_gap=50,
-            pf_coil_to_tf_coil_radial_gap=50,
+            pf_coil_radial_position=[200, 200, 200, 200],
+            pf_coil_vertical_position=[200, 100, -100, -200],
+            rear_blanket_to_tf_gap=50,
             outboard_tf_coil_radial_thickness=100,
             outboard_tf_coil_poloidal_thickness=50,
             gap_between_blankets=30,
@@ -39,15 +40,15 @@ class TestSegmentedBlanketBallReactor(unittest.TestCase):
 
         self.test_reactor.create_solids()
         small_gap_blanket_volume = self.test_reactor._blanket.volume
-        small_gap_fw_volume = self.test_reactor._firstwall.volume
+        small_gap_firstwall_volume = self.test_reactor._firstwall.volume
 
         self.test_reactor.gap_between_blankets = 60
         self.test_reactor.create_solids()
         large_gap_blanket_volume = self.test_reactor._blanket.volume
-        large_gap_fw_volume = self.test_reactor._firstwall.volume
+        large_gap_firstwall_volume = self.test_reactor._firstwall.volume
 
         assert small_gap_blanket_volume > large_gap_blanket_volume
-        assert small_gap_fw_volume > large_gap_fw_volume
+        assert small_gap_firstwall_volume > large_gap_firstwall_volume
 
     def test_number_of_blanket_segments_impacts_volume(self):
         """Creates a SegmentedBlanketBallReactor with different
@@ -56,15 +57,15 @@ class TestSegmentedBlanketBallReactor(unittest.TestCase):
 
         self.test_reactor.create_solids()
         blanket_volume_few_segments = self.test_reactor._blanket.volume
-        fw_volume_few_segments = self.test_reactor._firstwall.volume
+        firstwall_volume_few_segments = self.test_reactor._firstwall.volume
 
         self.test_reactor.number_of_blanket_segments = 6
         self.test_reactor.create_solids()
         blanket_volume_many_segments = self.test_reactor._blanket.volume
-        fw_volume_many_segments = self.test_reactor._firstwall.volume
+        firstwall_volume_many_segments = self.test_reactor._firstwall.volume
 
         assert blanket_volume_many_segments < blanket_volume_few_segments
-        assert fw_volume_many_segments > fw_volume_few_segments
+        assert firstwall_volume_many_segments > firstwall_volume_few_segments
 
     def test_invalid_parameter_error_raises(self):
         """Checks that the correct errors are raised when invalid arguments for
